import java.io.*;
import java.lang.*;
import java.lang.String.*;
import java.lang.System.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class main {

	public static void main(String [] args)
	{
		Pseudo_servlet pseudo = new Pseudo_servlet();

		MyHttpServletRequest req = new MyHttpServletRequest();
		MyHttpServletResponse res = new MyHttpServletResponse();

		req.setParameter("model_vehicle", "54");
		req.setParameter("model_vehicle", "54");
		req.setParameter("sub_model_vehicle", "Gasolina");
		req.setParameter("dies_lloguer", "1");
		req.setParameter("num_vehicles", "1");
		req.setParameter("descompte", "0.0");
		req.setParameter("llogar", "Llogar vehicle (GET)");
		try {
			pseudo.doGet(req, res);
		} catch (Exception e) {
			System.out.println("PATAPUM en el doGet: "+e.getMessage());
		}

		req.setParameter("model_vehicle", "54");
		req.setParameter("model_vehicle", "54");
		req.setParameter("sub_model_vehicle", "Diesel");
		req.setParameter("dies_lloguer", "2");
		req.setParameter("num_vehicles", "3");
		req.setParameter("descompte", "0.0");
		req.setParameter("llogar", "Llogar vehicle (GET)");
		try {
			pseudo.doGet(req, res);
		} catch (Exception e) {
			System.out.println("PATAPUM en el doGet: "+e.getMessage());
		}

		req.setParameter("userid", "foo");
		req.setParameter("password", "bar");
		req.setParameter("llistar_lloguers", "Llistar Lloguers (POST)");
		req.setParameter("", "");
		try {
			pseudo.doPost(req, res);
		} catch (Exception e) {
			System.out.println("PATAPUM en el doPost: "+e.getMessage());
		}
		
	}

}
