import java.io.*;
import java.lang.String.*;
import java.util.HashMap;

public class MyHttpServletRequest {
	private HashMap req;

	public MyHttpServletRequest() {
		req = new HashMap();
	}

	public void setParameter(String arg0, String arg1)
	{
		req.put(arg0, arg1);
	}

	public String getParameter(String arg0)
	{
		return (String)req.get(arg0);
	}
}

