import java.io.*;
import java.lang.String.*;

public class MyHttpServletResponse {

	public void MyHttpServletResponse () {
	}

	public void setContentType(String arg0) {
		System.out.println("======================================================================");
		System.out.println("setContentType("+arg0+")");
	}

	public PrintWriter getWriter() throws IOException {
		return new PrintWriter(System.out, true);
	}
}

